# NekUpload

**NekUpload** is a Python package for uploading Nektar++ datasets to a database. Automated validation and metadata extraction will occur, and the datasets will be submitted to the database admin for review. 